;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "speed-type" "1.7"
  "Practice touch and speed typing."
  '((emacs  "27.1")
    (compat "29.1.3"))
  :url "https://github.com/dakra/speed-type"
  :commit "2eb87803ed1349b10eef46ce0fe3eda0dbf42f00"
  :revdesc "2eb87803ed13"
  :keywords '("games")
  :maintainers '(("Daniel Kraus" . "daniel@kraus.my")))
